@@ -47,11 +47,11 @@ sub import {
 }
 
 
-our $VERSION = '0.0176';    # VERSION
+our $VERSION = '0.0177';    # VERSION
 
 1;
 
-# ABSTRACT: Perl Evo design pattern
+# ABSTRACT: Evo - the posmodern development framework
 
 __END__
 
@@ -61,11 +61,11 @@ __END__
 
 =head1 NAME
 
-Evo - Perl Evo design pattern
+Evo - Evo - the posmodern development framework
 
 =head1 VERSION
 
-version 0.0176
+version 0.0177
 
 =head1 DESCRIPTION
 
@@ -96,6 +96,11 @@ Exception handling in pure perl: L<Evo::Eval>, "try catch" alternative. Like C<T
 
 =back
 
+=head1 SYNOPSYS
+
+  # enables strict, warnings, utf8, :5.22, signatured, postderef
+  use Evo;
+
 =head1 IMPORTING
 
 Load Module and call it's C<import> method, emulating C<caller>. 
@@ -146,6 +151,8 @@ With or without options, C<use Evo> loads L<Evo::Default>:
   use experimental 'signatures';
   use feature 'postderef';
 
+I make some test and decided that using 5.22 and experimental features brings many benefits and worth it. This list will be expanded in the future, I hope
+
 =head2 -Loaded
 
 This marks inline or generated classes as loaded, so can be used with
