@@ -16,9 +16,11 @@ Evo::Comp
 
 =head1 VERSION
 
-version 0.0176
+version 0.0177
 
-=head1 Component-oriented programming
+=head1 DESCRIPTION
+
+=head2 Component-oriented programming
 
 A new promising component-oriented programming concepts. Documentation will be available if someone will be willing to help write it.
 
@@ -38,30 +40,60 @@ As you can see, we passed C<fo> instead of C<foo>, and Moose silently ignored it
 
 More explanation will be written later
 
-=head2 Usage
+=head1 SYNOPSYS
+
+  package main;
+  use Evo;
+
+  {
+
+    package My::Human;
+    use Evo '-Comp *';
+
+    has 'name' => 'unnamed';
+    has 'gender', is => 'ro', required => 1;
+    has age => check => sub($v) { $v >= 18 };
+  }
+
+  my $alex = My::Human::new(gender => 'male');
+
+  # default value "unnamed"
+  say $alex->name;
+
+  # fluent design
+  $alex->name('Alex')->age(18);
+  say $alex->name, ': ', $alex->age;
+
+  # will die, gender is required
+  My::Human::new();
+
+  # will die, age must be >= 18
+  My::Human::new(age => 17, gender => 'male');
+  My::Human::new()->age(17, gender => 'male');
+
+=head1 Usage
+
+=head2 creating component
+
+Describe a component, use need to import "*" to get it worked
 
   package My::Comp;
   use Evo '-Comp *';
   has 'simple';
-  has read_only => is => 'ro';
 
-  package main;
-  use Evo;
-  # if My::Comp in separate file
-  # use My::Comp;
-  
-  # !!!pay attantion, not My::Foo->new
-  my $foo = My::Foo::new(important => '22', read_only => 'hi');
-  $foo->simple('hello')->important(44);
-  say $foo->simple;
+You don't need to call something like C<__PACKAGE__-E<gt>meta-E<gt>make_immutable> unlike in L<Moose>, components are fast enough by design.
 
-We're protected from common mistakes
+=head2 new
 
-  # "SiMple" is unknown
-  my $foo = My::Foo::new(SiMple => 1, important => 1);
+B<important!!!>
+Because Components reuse code horizontal, there's no need to pass the class string to every invocation of C<new> (or C<Evo::Comp::Out/"init">). So instead of C<My::Class-E<gt>new> use C<My::Comp::new>
 
-  # "important" is required
-  my $foo = My::Foo::new();
+  my $foo = My::Comp::new(simple => 1);
+  my $foo2 = My::Comp::new();
+
+We're protected from common mistakes, because constructor won't accept unknown attributes
+
+  my $foo = My::Comp::new(SiMple => 1);
 
 =head2 Storage
 
